package cz.moneta.test.dsl.util.task.ufo.operations;

import cz.moneta.test.dsl.Harness;
import cz.moneta.test.dsl.ufo.operations.ufoOperations.STO704_S001_ClientConsentsPage;

import java.util.function.Function;

public class GdprTasks {

    private final Harness harness;

    public GdprTasks(Harness harness) {
        this.harness = harness;
    }

    public Function<STO704_S001_ClientConsentsPage, STO704_S001_ClientConsentsPage> checkIfEmailConsentIsChange() {
        return start -> start.checkEmailMMBConsents("odvolaný")
                .checkEmailMAConsents("odvolaný")
                .checkEmailMLConsents("odvolaný")
                .checkEmailWHBConsents("odvolaný")
                .checkEmailMSSConsents("odvolaný");
    }

    public Function<STO704_S001_ClientConsentsPage, STO704_S001_ClientConsentsPage> checkIfPostConsentIsChange() {
        return start -> start.checkPostMMBConsents("odvolaný")
                .checkPostMAConsents("odvolaný")
                .checkPostMLConsents("odvolaný")
                .checkPostWHBConsents("odvolaný")
                .checkPostMSSConsents("odvolaný");
    }

    public Function<STO704_S001_ClientConsentsPage, STO704_S001_ClientConsentsPage> checkIfTypeOfConsentAreChanged() {
        return start -> start.checkTypeOfConsent("Souhlas se zasíláním marketingových nabídek telefonem")
                .checkPostConsent("Souhlas se zasíláním marketingových nabídek poštou")
                .checkIBSBConsent("Souhlas se zasíláním marketingových nabídek do Internet Banky/SmartBanky")
                .checkSurveyConsent("Souhlas se zasíláním marketingových průzkumů")
                .checkSMSConsent("Souhlas se zasíláním marketingových nabídek SMS zprávou")
                .checkEmailConsent("Souhlas se zasíláním marketingových nabídek e-mailem (mj. ATM, Sociální sítě, Instant Messaging)");
    }
}
